@@ -17,8 +17,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_rename.c,v 1.16.2.6 2005/05/30 04:05:44 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -36,7 +34,7 @@ int
 afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
 	  char *aname2, struct AFS_UCRED *acred, struct vrequest *areq)
 {
-    register struct conn *tc;
+    register struct afs_conn *tc;
     register afs_int32 code;
     afs_int32 returnCode;
     int oneDir, doLocally;
@@ -227,7 +225,9 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
 		code = afs_dir_Delete(tdc2, aname2);
 	    }
 	    if (code == 0) {
+		ObtainWriteLock(&afs_xdcache, 292);
 		code = afs_dir_Create(tdc2, aname2, &fileFid.Fid);
+		ReleaseWriteLock(&afs_xdcache);
 	    }
 	    if (code != 0) {
 		ZapDCE(tdc1);
@@ -358,7 +358,7 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
 
 int
 #if defined(AFS_SGI_ENV)
-afs_rename(OSI_VC_DECL(aodp), char *aname1, struct vcache *andp, achar *name2, struct pathname *npnp, struct AFS_UCRED *acred)
+afs_rename(OSI_VC_DECL(aodp), char *aname1, struct vcache *andp, char *aname2, struct pathname *npnp, struct AFS_UCRED *acred)
 #else
 afs_rename(OSI_VC_DECL(aodp), char *aname1, struct vcache *andp, char *aname2, struct AFS_UCRED *acred)
 #endif
